#!/usr/bin/python
from distutils.core import setup
setup(
  name = 'cs.sh',
  description = 'Convenience functions for constructing shell commands.',
  author = 'Cameron Simpson',
  author_email = 'cs@zip.com.au',
  version = '20150118',
  url = 'https://bitbucket.org/cameron_simpson/css/commits/all',
  classifiers = ['Programming Language :: Python', 'Programming Language :: Python :: 2', 'Programming Language :: Python :: 3', 'Topic :: Software Development :: Libraries :: Python Modules', 'Operating System :: OS Independent', 'Development Status :: 4 - Beta', 'License :: OSI Approved :: GNU General Public License v3 (GPLv3)', 'Intended Audience :: Developers'],
  keywords = ['python2', 'python3'],
  long_description = u'Convenience functions for constructing shell commands\n-----------------------------------------------------\n\nFunctions for safely constructing shell command lines from bare strings.\nSomewhat like the inverse of the shlex stdlib module.\n',
  package_dir = {'': 'lib/python'},
  py_modules = ['cs.sh'],
)



#!/usr/bin/python
#
# Convenience functions for constructing shell commands.
#   - Cameron Simpson <cs@zip.com.au>
#

DISTINFO = {
    'description': "Convenience functions for constructing shell commands.",
    'keywords': ["python2", "python3"],
    'classifiers': [
        "Programming Language :: Python",
        "Programming Language :: Python :: 2",
        "Programming Language :: Python :: 3",
        ],
}

import string

# characters than do not need to be quoted
SAFECHARS = string.digits + string.ascii_letters + '-+_./:'

def quote(args):
  ''' Quote the supplied strings, return a list of the quoted strings.
  '''
  return [ quotestr(s) for s in args ]

def quotestr(s):
  ''' Quote a string for use on a shell command line.
  '''
  if not s:
    return "''"
  qparts = []
  start = offset = 0
  safemode = True       # not in quotes
  def flush():
    if offset > start:
      part = s[start:offset]
      if not safemode:
        if len(part) == 1:
          qparts.append("\\")
        else:
          qparts.append("'")
      qparts.append(s[start:offset])
      if not safemode:
        if len(part) > 1:
          qparts.append("'")
  while offset < len(s):
    c = s[offset]
    if c in "'\\":
      flush()
      start = offset
      qparts.append('\\')
      qparts.append(c)
      safemode = True
      start = offset + 1
    else:
      safe = s[offset] in SAFECHARS
      if safe ^ safemode:
        # mode change
        flush()
        safemode = safe
        start = offset
    offset += 1
  flush()
  return ''.join(qparts)
